@@ -3,3 +3,5 @@
 #include <Rinternals.h>
 
 extern "C" SEXP impl_readTabixByRange(SEXP arg_tabixFile, SEXP arg_range);
+extern "C" SEXP impl_readTabixHeader(SEXP arg_tabixFile);
+extern "C" SEXP impl_readTabixSkippedLine(SEXP arg_tabixFile);
